# goflow
This repository is all about simulating flow driven pruning in biological flow networks. 

##  Introduction

##  Installation
pip install goflow

##  Usage
./notebook contains examples to play with in the form of jupyter notebooks
##  Requirements
``` pandas ```,``` networkx ```, ``` numpy ```, ``` scipy ```, ``` kirchhoff ```, ``` hailhydro ```
##  Gallery

## Acknowledgement
```goflow``` written by Felix Kramer
